# Iron Toolbox
### Utilização da Biblioteca
Para importar a biblioteca, basta usar a nomenclatura **iron_toolbox**.
### Atualização da Biblioteca
Todo commit no repositório vai publicar a atualização automaticamente no **PyPI.org**, por isso sempre que 
for commitar qualquer atualização é necessário modificar a versão no arquivo **setup.py** em 
**setuptools.setup (...version='0.0.00'...)**.